<?php
/*
@package WordPress
@subpackage desire
*/
?>
<?php
/*************************** THEME OPTIONS ***************************/
/*********************************************************************/

/***************** Adding the javascripts & stylesheets to the head **********************/
/*****************************************************************************************/
function mytheme_enqueue_scripts($hook_suffix) {
    global $prefix;
    wp_enqueue_script('jquery'); //Adding the JQuery script
    wp_enqueue_script('media-upload'); //Adding the media upload script
    wp_enqueue_script('thickbox'); //Adding the thickbox script for media upload
    wp_enqueue_style('thickbox'); //Adding the thickbox stylesheet for media upload
    wp_register_style('jquery-ui',get_template_directory_uri() . '/inc/jquery-ui.css', false, false, 'all');
    wp_register_script('jquery-ui',get_template_directory_uri() . '/inc/jquery-ui.min.js', array('jquery'), false);
    wp_enqueue_style('jquery-ui');
    wp_enqueue_script('jquery-ui');
    wp_enqueue_script($prefix.'color_picker', get_template_directory_uri() . '/inc/jscolor.js', false, false);
    wp_enqueue_script($prefix.'admin_js', get_template_directory_uri() . '/inc/theme-options.js', array('jquery'), false); //Adding the theme option javascript
    wp_enqueue_style($prefix.'admin_css', get_template_directory_uri() . '/inc/theme-options.css', false, false, 'all'); //Adding the theme option stylesheet
}

/*************************** Initialize theme options ************************************/
/*****************************************************************************************/
function mytheme_initialize_options() {
    global $prefix;
    if(false === mytheme_get_options()) add_option($prefix.'theme_options', mytheme_get_default_options());
    register_setting($prefix.'options', $prefix.'theme_options', 'mytheme_validate_options');
}
add_action('admin_init', 'mytheme_initialize_options');

/*********************** Add theme options capability ******************************/
/***********************************************************************************/
function mytheme_options_page_capability($capability) {
    return 'edit_theme_options';
}
add_filter('option_page_capability_'.$prefix.'options', 'mytheme_options_page_capability');

/*********************** Add theme options to the menu ******************************/
/************************************************************************************/
function mytheme_add_options_page() {
    global $prefix, $themename;
    $theme_page = add_theme_page(__($themename.' Settings',$themename), __('Theme Settings',$themename), 'edit_theme_options', 'theme_options', 'mytheme_render_options_page');
    if(!$theme_page) return;
    add_action('admin_print_styles-' . $theme_page, 'mytheme_enqueue_scripts');
}
add_action('admin_menu', 'mytheme_add_options_page');

/*********************** Setting up preloaded option values ******************************/
/*****************************************************************************************/
function mytheme_body_font() {
    global $prefix, $themename;
    $body_font = array(
        'Helvetica, Arial, sans-serif' => array('value' => 'Helvetica, Arial, sans-serif', 'label' => __('Helvetica, Arial',$themename)),
        'Times New Roman, serif' => array('value' => 'Times New Roman, serif', 'label' => __('Times New Roman',$themename)),
        'Trebuchet MS, sans-serif' => array('value' => 'Trebuchet MS, sans-serif', 'label' => __('Trebuchet MS',$themename)),
        'Verdana, Geneva, sans-serif' => array('value' => 'Verdana, Geneva, sans-serif', 'label' => __('Verdana',$themename)),
        'Tahoma, Geneva, sans-serif' => array('value' => 'Tahoma, Geneva, sans-serif', 'label' => __('Tahoma',$themename)),
        'Georgia, serif' => array('value' => 'Georgia, serif', 'label' => __('Georgia',$themename)),
    );
    return apply_filters('mytheme_body_font', $body_font);
}

function mytheme_title_font() {
    global $prefix, $themename;
    $title_font = array(
        'Helvetica, Arial, sans-serif' => array('value' => 'Helvetica, Arial, sans-serif', 'label' => __('Helvetica, Arial',$themename)),
        'Times New Roman, serif' => array('value' => 'Times New Roman, serif', 'label' => __('Times New Roman',$themename)),
        'Trebuchet MS, sans-serif' => array('value' => 'Trebuchet MS, sans-serif', 'label' => __('Trebuchet MS',$themename)),
        'Verdana, Geneva, sans-serif' => array('value' => 'Verdana, Geneva, sans-serif', 'label' => __('Verdana',$themename)),
        'Tahoma, Geneva, sans-serif' => array('value' => 'Tahoma, Geneva, sans-serif', 'label' => __('Tahoma',$themename)),
        'Georgia, serif' => array('value' => 'Georgia, serif', 'label' => __('Georgia',$themename)),
    );
    return apply_filters('mytheme_title_font', $title_font);
}

function mytheme_content_heading_font() {
    global $prefix, $themename;
    $content_heading_font = array(
        'Helvetica, Arial, sans-serif' => array('value' => 'Helvetica, Arial, sans-serif', 'label' => __('Helvetica, Arial',$themename)),
        'Times New Roman, serif' => array('value' => 'Times New Roman, serif', 'label' => __('Times New Roman',$themename)),
        'Trebuchet MS, sans-serif' => array('value' => 'Trebuchet MS, sans-serif', 'label' => __('Trebuchet MS',$themename)),
        'Verdana, Geneva, sans-serif' => array('value' => 'Verdana, Geneva, sans-serif', 'label' => __('Verdana',$themename)),
        'Tahoma, Geneva, sans-serif' => array('value' => 'Tahoma, Geneva, sans-serif', 'label' => __('Tahoma',$themename)),
        'Georgia, serif' => array('value' => 'Georgia, serif', 'label' => __('Georgia',$themename)),
    );
    return apply_filters('mytheme_content_heading_font', $content_heading_font);
}

function mytheme_sidebar_heading_font() {
    global $prefix, $themename;
    $sidebar_heading_font = array(
        'Helvetica, Arial, sans-serif' => array('value' => 'Helvetica, Arial, sans-serif', 'label' => __('Helvetica, Arial',$themename)),
        'Times New Roman, serif' => array('value' => 'Times New Roman, serif', 'label' => __('Times New Roman',$themename)),
        'Trebuchet MS, sans-serif' => array('value' => 'Trebuchet MS, sans-serif', 'label' => __('Trebuchet MS',$themename)),
        'Verdana, Geneva, sans-serif' => array('value' => 'Verdana, Geneva, sans-serif', 'label' => __('Verdana',$themename)),
        'Tahoma, Geneva, sans-serif' => array('value' => 'Tahoma, Geneva, sans-serif', 'label' => __('Tahoma',$themename)),
        'Georgia, serif' => array('value' => 'Georgia, serif', 'label' => __('Georgia',$themename)),
    );
    return apply_filters('mytheme_sidebar_heading_font', $sidebar_heading_font);
}

function mytheme_sidebar_layout() {
    global $prefix, $themename;
    $sidebar_layout = array(
        'one-right-sidebar' => array('value' => 'one-right-sidebar', 'label' => __('One right sidebar',$themename)),
        'one-left-sidebar' => array('value' => 'one-left-sidebar', 'label' => __('One left sidebar',$themename)),
    );
    return apply_filters('mytheme_sidebar_layout', $sidebar_layout);
}

function mytheme_color_scheme() {
    global $prefix, $themename;
    $color_scheme = array(
        'light' => array('value' => 'light', 'label' => __('Light',$themename), 'bgcolor' => 'ffffff'),
        'dark' => array('value' => 'dark', 'label' => __('Dark',$themename), 'bgcolor' => '222222'),
    );
    return apply_filters('mytheme_color_scheme', $color_scheme);
}

function mytheme_background_repeat() {
    global $prefix, $themename;
    $bg_repeat = array(
        'repeat' => array('value' => 'repeat', 'label' => __('Repeat',$themename)),
        'repeat-x' => array('value' => 'repeat-x', 'label' => __('Repeat X',$themename)),
        'repeat-y' => array('value' => 'repeat-y', 'label' => __('Repeat Y',$themename)),
        'no-repeat' => array('value' => 'no-repeat', 'label' => __('No Repeat',$themename)),
    );
    return apply_filters('mytheme_background_repeat', $bg_repeat);
}

function mytheme_background_position() {
    global $prefix, $themename;
    $bg_position = array(
        'top left' => array('value' => 'top left', 'label' => __('Top Left',$themename)),
        'top right' => array('value' => 'top right', 'label' => __('Top Right',$themename)),
        'top center' => array('value' => 'top center', 'label' => __('Top Center',$themename)),
        'bottom left' => array('value' => 'bottom left', 'label' => __('Bottom Left',$themename)),
        'bottom right' => array('value' => 'bottom right', 'label' => __('Bottom Right',$themename)),
        'bottom center' => array('value' => 'bottom center', 'label' => __('Bottom Center',$themename)),
        'center left' => array('value' => 'center left', 'label' => __('Center Left',$themename)),
        'center right' => array('value' => 'center right', 'label' => __('Center Right',$themename)),
        'center center' => array('value' => 'center center', 'label' => __('Center Center',$themename)),
    );
    return apply_filters('mytheme_background_position', $bg_position);
}

function mytheme_background_scroll() {
    global $prefix, $themename;
    $bg_scroll = array(
        'scroll' => array('value' => 'scroll', 'label' => __('Scroll',$themename)),
        'fixed' => array('value' => 'fixed', 'label' => __('Fixed',$themename)),
    );
    return apply_filters('mytheme_background_scroll', $bg_scroll);
}

function mytheme_blog_style() {
    global $prefix, $themename;
    $blog_style = array(
        'standard' => array('value' => 'standard', 'label' => __('Standard',$themename)),
        'magazine' => array('value' => 'magazine', 'label' => __('Magazine',$themename)),
    );
    return apply_filters('mytheme_blog_style', $blog_style);
}

/*********************** Setting up default theme options ********************************/
/*****************************************************************************************/
function mytheme_get_default_options() {
    $default_options = array(
        'current_tab' => 'tab1',
        'body_font' => 'Helvetica, Arial, sans-serif',
        'content_heading_font' => 'Helvetica, Arial, sans-serif',
        'sidebar_heading_font' => 'Helvetica, Arial, sans-serif',
        'title_font' => 'Helvetica, Arial, sans-serif',
        'sidebar_layout' => 'one-right-sidebar',          
        'color_scheme' => 'light',
        'content_width' => 600,
        'sidebar_width' => 230,
        'enable_slideshow' => true,
        'slideshow_count' => 5,
        'logo_image' => '',
        'favicon_image' => '',
        'background_color' => $bgcolor,
        'background_image' => '',
        'background_repeat' => 'repeat',
        'background_position' => 'top left',
        'background_scroll' => 'fixed',
        'blog_style' => 'standard',
        'show_excerpts' => false,
        'show_breadcrumbs' => true,
        'show_search' => true,
        'social_facebook' => '',
        'social_twitter' => '',
        'social_delicious' => '',
        'social_flickr' => '',
        'social_youtube' => '',
        'social_vimeo' => '',
        'enable_rss' => '',
        'custom_css' => '',
    );
    return apply_filters('mytheme_get_default_options', $default_options);
}

/************************** Retrieving theme options *************************************/
/*****************************************************************************************/
function mytheme_get_options() {
    global $prefix, $themename;
    return get_option($prefix.'theme_options', mytheme_get_default_options());
}

/************************** Displaying theme options page *************************************/
/**********************************************************************************************/
function mytheme_render_options_page() {
    global $prefix, $themename;
    if(isset($_POST['mytheme_reset_button'])) {
        delete_option($prefix.'theme_options');
        add_settings_error('','','Default settings restored.','updated');
    }
?>
<div class="wrap"> <!-- Start of wrap -->    
    <h1 class="theme-title"><?php echo $themename.__(' Theme Settings',$themename); ?></h1>
    <?php settings_errors(); ?>
    <div class="tab-area">
        <div class="tab current-tab" id="tab1"><?php _e('Font and Color',$themename); ?></div>
        <div class="tab" id="tab2"><?php _e('Background',$themename); ?></div>
        <div class="tab" id="tab3"><?php _e('Logo and Favicon',$themename); ?></div>
        <div class="tab" id="tab4"><?php _e('Layout',$themename); ?></div>
        <div class="tab" id="tab5"><?php _e('Slideshow',$themename); ?></div>
        <div class="tab" id="tab6"><?php _e('Blog',$themename); ?></div>
        <div class="tab" id="tab7"><?php _e('Social Links',$themename); ?></div>
        <div class="tab" id="tab8"><?php _e('Custom CSS',$themename); ?></div>
    </div>
    <div class="section-area">
        <form class="form" method="post" id="mytheme-form" action="options.php">
        <?php
            settings_fields( $prefix.'options' );                   
            $options = mytheme_get_options();                    
            $default_options = mytheme_get_default_options();
        ?>
        <div class="section current-section" id="section1">
            <table class="form-table" cellpadding="0" cellspacing="0">
                <tr>
                    <td class="label"><label><?php _e('Content text typography: ',$themename); ?></label></td>
                    <td class="field">
                        <label><?php _e('Font: ',$themename); ?></label>
                        <select name="<?php echo $prefix; ?>theme_options[body_font]">
                            <?php foreach (mytheme_body_font() as $body_font) { ?>
                                <option value="<?php echo $body_font['value']; ?>" <?php selected( $options['body_font'], $body_font['value'] ); ?>><?php echo $body_font['label']; ?></option>
                            <?php } ?>
                        </select>
                    </td>
                </tr>                
                <tr>
                    <td class="label"><label><?php _e('Content Heading typography: ',$themename); ?></label></td>
                    <td class="field">
                        <label><?php _e('Font: ',$themename); ?></label>
                        <select name="<?php echo $prefix; ?>theme_options[content_heading_font]">
                            <?php foreach (mytheme_content_heading_font() as $content_heading_font) { ?>
                                <option value="<?php echo $content_heading_font['value']; ?>" <?php selected( $options['content_heading_font'], $content_heading_font['value'] ); ?>><?php echo $content_heading_font['label']; ?></option>
                            <?php } ?>
                        </select>                        
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Sidebar Heading typography: ',$themename); ?></label></td>
                    <td class="field">
                        <label><?php _e('Font: ',$themename); ?></label>
                        <select name="<?php echo $prefix; ?>theme_options[sidebar_heading_font]">
                            <?php foreach (mytheme_sidebar_heading_font() as $sidebar_heading_font) { ?>
                                <option value="<?php echo $sidebar_heading_font['value']; ?>" <?php selected( $options['sidebar_heading_font'], $sidebar_heading_font['value'] ); ?>><?php echo $sidebar_heading_font['label']; ?></option>
                            <?php } ?>
                        </select>                        
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Main Title typography: ',$themename); ?></label></td>
                    <td class="field">
                        <label><?php _e('Font: ',$themename); ?></label>
                        <select name="<?php echo $prefix; ?>theme_options[title_font]">
                            <?php foreach (mytheme_title_font() as $title_font) { ?>
                                <option value="<?php echo $title_font['value']; ?>" <?php selected( $options['title_font'], $title_font['value'] ); ?>><?php echo $title_font['label']; ?></option>
                            <?php } ?>
                        </select>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Color Scheme for your site: ',$themename); ?></label></td>
                    <td class="field">
                        <?php foreach(mytheme_color_scheme() as $color_scheme) { ?>
                            <?php if($options['color_scheme'] == $color_scheme['value']) $class = ' current-img'; else $class = ''; ?>
                            <img title="<?php echo $color_scheme['label']; ?>" class="img-select img-scheme<?php echo $class; ?>" id="<?php echo $color_scheme['value']; ?>-scheme" style="background-color: #<?php echo $color_scheme['bgcolor']; ?>;" src="<?php echo get_template_directory_uri(); ?>/inc/images/image_bg.png"/>
                        <?php } ?>
                        <input type="hidden" name="<?php echo $prefix; ?>theme_options[color_scheme]" id="color-scheme" value="<?php echo $options['color_scheme']; ?>"/>
                    </td>
                </tr>
            </table>
        </div>
        
        <div class="section" id="section2">
            <table class="form-table" cellpadding="0" cellspacing="0">
                <tr>
                    <td class="label"><label><?php _e('Background Color: ',$themename); ?></label></td>
                    <td class="field">                        
                        <input type="text" name="<?php echo $prefix; ?>theme_options[background_color]" id="background-color" class="color" value="<?php echo esc_attr( $options['background_color'] ); ?>"/>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Background Image: ',$themename); ?></label></td>
                    <td class="field">                        
                        <input type="text" name="<?php echo $prefix; ?>theme_options[background_image]" id="background-upload" size="36" value="<?php echo esc_attr( $options['background_image'] ); ?>"/>
                        <input id="background-upload-button" type="button" class="upload_img button-secondary" value="<?php _e('Upload Backgound Image',$themename); ?>" />
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Background Image Repeat: ',$themename); ?></label></td>
                    <td class="field">                        
                        <select name="<?php echo $prefix; ?>theme_options[background_repeat]">
                            <?php foreach (mytheme_background_repeat() as $background_repeat) { ?>
                                <option value="<?php echo $background_repeat['value']; ?>" <?php selected( $options['background_repeat'], $background_repeat['value'] ); ?>><?php echo $background_repeat['label']; ?></option>
                            <?php } ?>
                        </select>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Background Image Position: ',$themename); ?></label></td>
                    <td class="field">                        
                        <select name="<?php echo $prefix; ?>theme_options[background_position]">
                            <?php foreach (mytheme_background_position() as $background_position) { ?>
                                <option value="<?php echo $background_position['value']; ?>" <?php selected( $options['background_position'], $background_position['value'] ); ?>><?php echo $background_position['label']; ?></option>
                            <?php } ?>
                        </select>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Background Image Scroll: ',$themename); ?></label></td>
                    <td class="field">                        
                        <select name="<?php echo $prefix; ?>theme_options[background_scroll]">
                            <?php foreach (mytheme_background_scroll() as $background_scroll) { ?>
                                <option value="<?php echo $background_scroll['value']; ?>" <?php selected( $options['background_scroll'], $background_scroll['value'] ); ?>><?php echo $background_scroll['label']; ?></option>
                            <?php } ?>
                        </select>
                    </td>
                </tr>
            </table>
        </div>
        
        <div class="section" id="section3">
            <table class="form-table" cellpadding="0" cellspacing="0">
                <tr>
                    <td class="label"><label><?php _e('Custom Logo: ',$themename); ?></label></td>
                    <td class="field">                        
                        <input type="text" name="<?php echo $prefix; ?>theme_options[logo_image]" id="logo-upload" size="36" value="<?php echo esc_attr( $options['logo_image'] ); ?>"/>
                        <input id="logo-upload-button" type="button" class="upload_img button-secondary" value="<?php _e('Upload Logo',$themename); ?>" />
                    </td>
                    <td class="meta">
                        <?php _e('Upload 200 x 200px image for best results',$themename); ?>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Custom favicon: ',$themename); ?></label></td>
                    <td class="field">                        
                        <input type="text" name="<?php echo $prefix; ?>theme_options[favicon_image]" id="favicon-upload" size="36" value="<?php echo esc_attr( $options['favicon_image'] ); ?>"/>
                        <input id="favicon-upload-button" type="button" class="upload_img button-secondary" value="<?php _e('Upload Favicon',$themename); ?>" />
                    </td>
                    <td class="meta">
                        <?php _e('Favicon image cannot exceed 16x16 pixels. (.ico image format recommended)',$themename); ?>
                    </td>
                </tr>
            </table>
        </div>
        
        <div class="section" id="section4">
            <table class="form-table" cellpadding="0" cellspacing="0">
                <tr>
                    <td class="label"><label><?php _e('Layout for sidebar: ',$themename); ?></label></td>
                    <td class="field">
                        <?php foreach(mytheme_sidebar_layout() as $sidebar_layout) { ?>
                            <?php if($options['sidebar_layout'] == $sidebar_layout['value']) $class = ' current-img'; else $class = ''; ?>
                            <img title="<?php echo $sidebar_layout['label']; ?>" class="img-select img-layout<?php echo $class; ?>" id="<?php echo $sidebar_layout['value']; ?>-layout" src="<?php echo get_template_directory_uri(); ?>/inc/images/<?php echo $sidebar_layout['value']; ?>.png"/>
                        <?php } ?>
                        <input type="hidden" name="<?php echo $prefix; ?>theme_options[sidebar_layout]" id="sidebar-layout" value="<?php echo $options['sidebar_layout']; ?>"/>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Content width: ',$themename); ?></label></td>
                    <td class="field">
                        <div class="content-width-slider" id="slider"></div>                                                
                    </td>
                    <td><span class="width-txt"><input type="text" readonly="readonly" name="<?php echo $prefix; ?>theme_options[content_width]" id="content-width" value="<?php echo $options['content_width']; ?>"/> <?php _e('px',$themename); ?></span></td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Sidebar width: ',$themename); ?></label></td>
                    <td class="field">
                        <div class="sidebar-width-slider" id="slider"></div>                                                
                    </td>
                    <td><span class="width-txt"><input type="text" readonly="readonly" name="<?php echo $prefix; ?>theme_options[sidebar_width]" id="sidebar-width" value="<?php echo $options['sidebar_width']; ?>"/> <?php _e('px',$themename); ?></span></td>
                </tr>
            </table>
        </div>
        
        <div class="section" id="section5">
            <p><?php _e('Refer to the <strong><u>Word Document in the documentation folder</u></strong> on how to add new items to your slideshow',$themename); ?></p>
            <table class="form-table" cellpadding="0" cellspacing="0">
                <tr>
                    <td class="label"><label><?php _e('Enable Post Slideshow on front page ?: ',$themename); ?></label></td>
                    <td class="field">
                        <input type="checkbox" name="<?php echo $prefix; ?>theme_options[enable_slideshow]" value="true" <?php checked(true,$options['enable_slideshow']); ?> />
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Number of entries to display in slideshow: ',$themename); ?></label></td>
                    <td class="field">
                        <input type="text" name="<?php echo $prefix; ?>theme_options[slideshow_count]" value="<?php echo esc_attr($options['slideshow_count']); ?>"/>
                    </td>
                </tr>
            </table>
        </div>        
        
        <div class="section" id="section6">
            <table class="form-table" cellpadding="0" cellspacing="0">
                <tr>
                    <td class="label"><label><?php _e('Blog style: ',$themename); ?></label></td>
                    <td class="field">                        
                        <select name="<?php echo $prefix; ?>theme_options[blog_style]">
                            <?php foreach (mytheme_blog_style() as $blog_style) { ?>
                                <option value="<?php echo $blog_style['value']; ?>" <?php selected( $options['blog_style'], $blog_style['value'] ); ?>><?php echo $blog_style['label']; ?></option>
                            <?php } ?>
                        </select>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Show post excerpts <br/>for non-single pages ?: ',$themename); ?></label></td>
                    <td class="field">
                        <input type="checkbox" name="<?php echo $prefix; ?>theme_options[show_excerpts]" value="true" <?php checked(true,$options['show_excerpts']); ?> />
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Show post breadcrumbs ?: ',$themename); ?></label></td>
                    <td class="field">
                        <input type="checkbox" name="<?php echo $prefix; ?>theme_options[show_breadcrumbs]" value="true" <?php checked(true,$options['show_breadcrumbs']); ?> />
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Show default search widget in sidebar ?: ',$themename); ?></label></td>
                    <td class="field">
                        <input type="checkbox" name="<?php echo $prefix; ?>theme_options[show_search]" value="true" <?php checked(true,$options['show_search']); ?> />
                    </td>
                </tr>
            </table>
        </div>
        
        <div class="section" id="section7">
            <p><strong><?php _e('Enter the username for the social links you want to display in your site',$themename); ?></strong></p>
            <table class="form-table" cellpadding="0" cellspacing="0">
                <tr>
                    <td class="label"><label><?php _e('Facebook: ',$themename); ?></label></td>
                    <td class="field">
                        <img class="social-icon" src="<?php echo get_template_directory_uri(); ?>/inc/images/social/facebook.png"/>
                        <input type="text" name="<?php echo $prefix; ?>theme_options[social_facebook]" value="<?php echo esc_attr($options['social_facebook']); ?>"/>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Twitter: ',$themename); ?></label></td>
                    <td class="field">
                        <img class="social-icon" src="<?php echo get_template_directory_uri(); ?>/inc/images/social/twitter.png"/>
                        <input type="text" name="<?php echo $prefix; ?>theme_options[social_twitter]" value="<?php echo esc_attr($options['social_twitter']); ?>"/>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Delicious: ',$themename); ?></label></td>
                    <td class="field">
                        <img class="social-icon" src="<?php echo get_template_directory_uri(); ?>/inc/images/social/delicious.png"/>
                        <input type="text" name="<?php echo $prefix; ?>theme_options[social_delicious]" value="<?php echo esc_attr($options['social_delicious']); ?>"/>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Flickr: ',$themename); ?></label></td>
                    <td class="field">
                        <img class="social-icon" src="<?php echo get_template_directory_uri(); ?>/inc/images/social/flickr.png"/>
                        <input type="text" name="<?php echo $prefix; ?>theme_options[social_flickr]" value="<?php echo esc_attr($options['social_flickr']); ?>"/>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('YouTube: ',$themename); ?></label></td>
                    <td class="field">
                        <img class="social-icon" src="<?php echo get_template_directory_uri(); ?>/inc/images/social/youtube.png"/>
                        <input type="text" name="<?php echo $prefix; ?>theme_options[social_youtube]" value="<?php echo esc_attr($options['social_youtube']); ?>"/>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Vimeo: ',$themename); ?></label></td>
                    <td class="field">
                        <img class="social-icon" src="<?php echo get_template_directory_uri(); ?>/inc/images/social/vimeo.png"/>
                        <input type="text" name="<?php echo $prefix; ?>theme_options[social_vimeo]" value="<?php echo esc_attr($options['social_vimeo']); ?>"/>
                    </td>
                </tr>
                <tr>
                    <td class="label"><label><?php _e('Display RSS Icon?: ',$themename); ?></label></td>
                    <td class="field">
                        <img class="social-icon" src="<?php echo get_template_directory_uri(); ?>/inc/images/social/rss.png"/>
                        <input type="checkbox" name="<?php echo $prefix; ?>theme_options[enable_rss]" value="true" <?php checked(true,$options['enable_rss']); ?> />
                    </td>
                </tr>
            </table>
        </div>
        
        <div class="section" id="section8">
            <p><?php _e('You can enter your own custom style statements here',$themename); ?></p>
            <table class="form-table" cellpadding="0" cellspacing="0">
                <tr>
                    <td class="label"><label><?php _e('Custom CSS: ',$themename); ?></label></td>
                    <td class="field">
                        <textarea rows="10" cols="70" name="<?php echo $prefix; ?>theme_options[custom_css]"><?php echo esc_attr($options['custom_css']); ?></textarea>
                    </td>
                </tr>
            </table>
        </div>
        
        <input type="hidden" name="<?php echo $prefix; ?>theme_options[current_tab]" id="current-tab-hidden" value="<?php if($_GET['settings-updated'] == true) echo esc_attr( $options['current_tab'] ); ?>"/>
        <hr class="hrline"/>
        <?php submit_button(); ?>
        </form>
        <form class="form" method="post" id="mytheme-reset-form" style="margin-bottom: 20px;">
            <input type="submit" class="button-secondary" name="mytheme_reset_button" id="mytheme_reset_button" value="<?php _e('Reset settings',$themename); ?>" />            
        </form>
        <hr class="hrline"/>
        <!-- Donate Button -->            
        <form action="https://www.paypal.com/cgi-bin/webscr" method="post" style="margin-top:10px;">
            <input type="hidden" name="cmd" value="_s-xclick">
            <input type="hidden" name="hosted_button_id" value="5GY3AWKND3GTC">
            <input style="vertical-align: middle;" type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
            <img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
            <label style="margin-left:5px;"><strong><?php _e('Feel free to donate as an appreciation for my time and effort to develop this theme',$themename); ?></strong></label>
        </form>
    </div>
    <div class="credit"><?php echo ucwords($themename); ?> <?php _e('Theme designed and developed by Nischal Maniar',$themename); ?></div>
</div> <!-- End of wrap -->
<?php
}

/******************************* Validating theme options *************************************/
/**********************************************************************************************/
function mytheme_validate_options($input) {
    global $prefix, $themename;
    $output = $defaults = mytheme_get_default_options();
    
    //Validating array items
    if (isset($input['body_font']) && array_key_exists($input['body_font'], mytheme_body_font()) )
	$output['body_font'] = $input['body_font'];
    if (isset($input['title_font']) && array_key_exists($input['title_font'], mytheme_title_font()) )
	$output['title_font'] = $input['title_font'];
    if (isset($input['content_heading_font']) && array_key_exists($input['content_heading_font'], mytheme_content_heading_font()) )
	$output['content_heading_font'] = $input['content_heading_font'];
    if (isset($input['sidebar_heading_font']) && array_key_exists($input['sidebar_heading_font'], mytheme_sidebar_heading_font()) )
	$output['sidebar_heading_font'] = $input['sidebar_heading_font'];
    if (isset($input['sidebar_layout']) && array_key_exists($input['sidebar_layout'], mytheme_sidebar_layout()) )
	$output['sidebar_layout'] = $input['sidebar_layout'];
    if (isset($input['color_scheme']) && array_key_exists($input['color_scheme'], mytheme_color_scheme()) )
	$output['color_scheme'] = $input['color_scheme'];
    if (isset($input['background_repeat']) && array_key_exists($input['background_repeat'], mytheme_background_repeat()) )
	$output['background_repeat'] = $input['background_repeat'];
    if (isset($input['background_position']) && array_key_exists($input['background_position'], mytheme_background_position()) )
	$output['background_position'] = $input['background_position'];
    if (isset($input['background_scroll']) && array_key_exists($input['background_scroll'], mytheme_background_scroll()) )
	$output['background_scroll'] = $input['background_scroll'];
    if (isset($input['blog_style']) && array_key_exists($input['blog_style'], mytheme_blog_style()) )
	$output['blog_style'] = $input['blog_style'];
        
    //Validating hidden fields
    if($input['current_tab'] == "") $output['current_tab'] = 'tab1';
    else $output['current_tab'] = $input['current_tab'];
    
    //Validating color fields
    if(validate_color($input['background_color']))
        $output['background_color'] = $input['background_color'];
    else
        add_settings_error( $prefix.'options', 'invalid-color', 'Invalid Hex Color', 'error' );
     
    //Validating integer fields
    if(false == filter_var($input['content_width'],FILTER_VALIDATE_INT))
        add_settings_error( $prefix.'options', 'invalid-content-width', 'Content width should be a number', 'error' );
    else if($input['content_width'] < 200 or $input['content_width'] > 1000)
        add_settings_error( $prefix.'options', 'invalid-content-width', 'Content width should be between 200 and 1000 pixels', 'error' );
    else $output['content_width'] = $input['content_width'];
    
    if(false == filter_var($input['sidebar_width'],FILTER_VALIDATE_INT))
        add_settings_error( $prefix.'options', 'invalid-sidebar-width', 'Sidebar width should be a number', 'error' );
    else if(intval($input['sidebar_width']) < 200 or intval($input['sidebar_width']) > 1000)
        add_settings_error( $prefix.'options', 'invalid-sidebar-width', 'Sidebar width should be between 100 and 350 pixels', 'error' );
    else $output['sidebar_width'] = $input['sidebar_width'];
    
    if(false == filter_var($input['slideshow_count'],FILTER_VALIDATE_INT))
        add_settings_error( $prefix.'options', 'invalid-slideshow-count', 'Slideshow count should be a number', 'error' );
    else $output['slideshow_count'] = $input['slideshow_count'];
        
    //Validating text fields
    if(trim($input['social_facebook']) != "" and !validate_social_user($input['social_facebook']))
        add_settings_error( $prefix.'options', 'invalid-username', 'Invalid facebook username', 'error' );
    else $output['social_facebook'] = trim($input['social_facebook']);
    
    if(trim($input['social_twitter']) != "" and !validate_social_user($input['social_twitter']))
        add_settings_error( $prefix.'options', 'invalid-username', 'Invalid twitter username', 'error' );
    else $output['social_twitter'] = trim($input['social_twitter']);
    
    if(trim($input['social_delicious']) != "" and !validate_social_user($input['social_delicious']))
        add_settings_error( $prefix.'options', 'invalid-username', 'Invalid delicious username', 'error' );
    else $output['social_delicious'] = trim($input['social_delicious']);
    
    if(trim($input['social_flickr']) != "" and !validate_social_user($input['social_flickr']))
        add_settings_error( $prefix.'options', 'invalid-username', 'Invalid flickr username', 'error' );
    else $output['social_flickr'] = trim($input['social_flickr']);
    
    if(trim($input['social_youtube']) != "" and !validate_social_user($input['social_youtube']))
        add_settings_error( $prefix.'options', 'invalid-username', 'Invalid youtube username', 'error' );
    else $output['social_youtube'] = trim($input['social_youtube']);
    
    if(trim($input['social_vimeo']) != "" and !validate_social_user($input['social_vimeo']))
        add_settings_error( $prefix.'options', 'invalid-username', 'Invalid vimeo username', 'error' );
    else $output['social_vimeo'] = trim($input['social_vimeo']);
    
    $output['custom_css'] = wp_filter_nohtml_kses($input['custom_css']);
    
    //Validating image upload fields
    if(trim($input['background_image']) != "" and !validate_image_url($input['background_image']))
        add_settings_error( $prefix.'options', 'invalid-background-image', 'Invalid background image URL', 'error' );
    else $output['background_image'] = trim($input['background_image']);
    
    if(trim($input['logo_image']) != "" and !validate_image_url($input['logo_image']))
        add_settings_error( $prefix.'options', 'invalid-logo-image', 'Invalid logo image URL', 'error' );
    else $output['logo_image'] = trim($input['logo_image']);
    
    if(trim($input['favicon_image']) != "" and !validate_image_url($input['favicon_image']))
        add_settings_error( $prefix.'options', 'invalid-favicon-image', 'Invalid favicon image URL', 'error' );
    else if(trim($input['favicon_image']) != "" and !validate_image_size($input['favicon_image'],16,16))
        add_settings_error( $prefix.'options', 'invalid-favicon-image', 'Favicon width/height cannot exceed 16 x 16 pixels', 'error' );
    else $output['favicon_image'] = trim($input['favicon_image']);
    
    //Validating all the checkboxes
    $chkboxinputs = array('enable_slideshow','enable_rss','show_excerpts','show_breadcrumbs','show_search');
    foreach($chkboxinputs as $chkbox) {
        if (!isset($input[$chkbox]))
            $input[$chkbox] = null;                
        $output[$chkbox] = ( $input[$chkbox] == true ? true : false );
    }

    return apply_filters( 'mytheme_validate_options', $output, $input, $defaults );
}

function validate_color($color) {
    $exp = "/([A-Za-z0-9])/";
    if(!preg_match($exp,$color))
        return false;
    else
        return true;
}

function validate_image_url($url) {
    $exp = "/^https?:\/\/(.)*\.(jpg|png|gif|ico)$/i";
    if(!preg_match($exp,$url))
        return false;
    else
        return true;
}

function validate_image_size($url,$width,$height) {
    $size = getimagesize($url);
    if($size[0] > $width or $size[1] > $height)
        return false;
    else
        return true;
}

function validate_social_user($user) {
    $exp = "/^([a-zA-Z0-9])+([a-zA-Z0-9\._-])*$/";
    if(!preg_match($exp,$user))
        return false;
    else
        return true;
}
?>
